summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMax Kremmel <xing@synapse.plus.com>2006-02-06 00:12:23 +0000
committerMax Kremmel <xing@synapse.plus.com>2006-02-06 00:12:23 +0000
commit42a1854034954b840d0d83de4d1a460060cecd97 (patch)
tree9b3ef624bb824956c50875c024c8cd8cc57dc87d
parent7a1f6470543b0d78d22485a8bd4a1c9c2f4ca768 (diff)
downloadwiki-42a1854034954b840d0d83de4d1a460060cecd97.tar.gz
wiki-42a1854034954b840d0d83de4d1a460060cecd97.tar.bz2
wiki-42a1854034954b840d0d83de4d1a460060cecd97.zip
more preference standardisation
-rw-r--r--BitPage.php60
-rw-r--r--admin/admin_external_wikis.php16
-rw-r--r--admin/admin_wiki_inc.php32
-rw-r--r--admin/schema_inc.php16
-rw-r--r--bit_setup_inc.php2
-rw-r--r--index.php10
-rw-r--r--like_pages.php6
-rw-r--r--list_pages.php22
-rw-r--r--lookup_page_inc.php6
-rw-r--r--orphan_pages.php22
-rw-r--r--page_history.php10
-rw-r--r--print.php10
-rw-r--r--received_pages.php18
-rwxr-xr-xslideshow.php10
-rw-r--r--templates/edit_page.tpl8
-rw-r--r--wiki_rss.php6
16 files changed, 127 insertions, 127 deletions
diff --git a/admin/admin_external_wikis.php b/admin/admin_external_wikis.php
index 53ae829..3c43660 100644
--- a/admin/admin_external_wikis.php
+++ b/admin/admin_external_wikis.php
@@ -1,5 +1,5 @@
<?php
-// $Header: /cvsroot/bitweaver/_bit_wiki/admin/admin_external_wikis.php,v 1.2 2005/08/01 18:42:05 squareing Exp $
+// $Header: /cvsroot/bitweaver/_bit_wiki/admin/admin_external_wikis.php,v 1.3 2006/02/06 00:12:23 squareing Exp $
// Copyright (c) 2002-2003, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
// All Rights Reserved. See copyright.txt for details and a complete list of authors.
// Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
@@ -49,7 +49,7 @@ if (!isset($_REQUEST["offset"])) {
}
if (isset($_REQUEST['page'])) {
$page = &$_REQUEST['page'];
- $offset = ($page - 1) * $maxRecords;
+ $offset = ($page - 1) * $max_records;
}
$gBitSmarty->assign_by_ref('offset', $offset);
if (isset($_REQUEST["find"])) {
@@ -59,18 +59,18 @@ if (isset($_REQUEST["find"])) {
}
$gBitSmarty->assign_by_ref('find', $find);
-$channels = $adminlib->list_extwiki($offset, $maxRecords, $sort_mode, $find);
-$cant_pages = ceil($channels["cant"] / $maxRecords);
+$channels = $adminlib->list_extwiki($offset, $max_records, $sort_mode, $find);
+$cant_pages = ceil($channels["cant"] / $max_records);
$gBitSmarty->assign_by_ref('cant_pages', $cant_pages);
-$gBitSmarty->assign('actual_page', 1 + ($offset / $maxRecords));
-if ($channels["cant"] > ($offset + $maxRecords)) {
- $gBitSmarty->assign('next_offset', $offset + $maxRecords);
+$gBitSmarty->assign('actual_page', 1 + ($offset / $max_records));
+if ($channels["cant"] > ($offset + $max_records)) {
+ $gBitSmarty->assign('next_offset', $offset + $max_records);
} else {
$gBitSmarty->assign('next_offset', -1);
}
// If offset is > 0 then prev_offset
if ($offset > 0) {
- $gBitSmarty->assign('prev_offset', $offset - $maxRecords);
+ $gBitSmarty->assign('prev_offset', $offset - $max_records);
} else {
$gBitSmarty->assign('prev_offset', -1);
}
diff --git a/admin/admin_wiki_inc.php b/admin/admin_wiki_inc.php
index 53684e3..2cd0ed1 100644
--- a/admin/admin_wiki_inc.php
+++ b/admin/admin_wiki_inc.php
@@ -1,5 +1,5 @@
<?php
-// $Header: /cvsroot/bitweaver/_bit_wiki/admin/admin_wiki_inc.php,v 1.12 2006/02/04 10:10:51 squareing Exp $
+// $Header: /cvsroot/bitweaver/_bit_wiki/admin/admin_wiki_inc.php,v 1.13 2006/02/06 00:12:23 squareing Exp $
// Copyright (c) 2002-2003, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
// All Rights Reserved. See copyright.txt for details and a complete list of authors.
// Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
@@ -75,7 +75,7 @@ $formWikiFeatures = array(
'label' => 'Backlinks',
'note' => 'Display a dropdown list of pages that link to a page.',
),
- "feature_likePages" => array(
+ "feature_like_pages" => array(
'label' => 'Like Pages',
'note' => 'Display a list of pages that have a common word in the names.',
),
@@ -87,7 +87,7 @@ $formWikiFeatures = array(
'label' => 'History',
'note' => 'Allow access to the page\'s history.',
),
- "feature_listPages" => array(
+ "feature_list_pages" => array(
'label' => 'List Pages',
'note' => 'Allow access to a listing of all wikipages.',
),
@@ -312,8 +312,8 @@ if (isset($_REQUEST["removetag"])) {
}
if (isset($_REQUEST["setwikihome"])) {
- $gBitSystem->storePreference('wikiHomePage', $_REQUEST["wikiHomePage"]);
- $gBitSmarty->assign('wikiHomePage', $_REQUEST["wikiHomePage"]);
+ $gBitSystem->storePreference('wiki_home_page', $_REQUEST["wiki_home_page"]);
+ $gBitSmarty->assign('wiki_home_page', $_REQUEST["wiki_home_page"]);
}
if (isset($_REQUEST["wikidiscussprefs"])) {
@@ -334,8 +334,8 @@ if (isset($_REQUEST["setwikiregex"])) {
}
if (isset($_REQUEST["wikisetprefs"])) {
- if (isset($_REQUEST["maxVersions"])) {
- $gBitSystem->storePreference("maxVersions", $_REQUEST["maxVersions"]);
+ if (isset($_REQUEST["max_versions"])) {
+ $gBitSystem->storePreference("max_versions", $_REQUEST["max_versions"]);
}
if (isset($_REQUEST["keep_versions"])) {
$gBitSystem->storePreference("keep_versions", $_REQUEST["keep_versions"]);
@@ -345,23 +345,23 @@ if (isset($_REQUEST["wikisetprefs"])) {
if (isset($_REQUEST["wikisetcopyright"])) {
simple_set_toggle( 'wiki_feature_copyrights','wiki' );
- if (isset($_REQUEST["wikiLicensePage"])) {
- $gBitSystem->storePreference("wikiLicensePage", $_REQUEST["wikiLicensePage"]);
- $gBitSmarty->assign('wikiLicensePage', $_REQUEST["wikiLicensePage"]);
+ if (isset($_REQUEST["wiki_license_page"])) {
+ $gBitSystem->storePreference("wiki_license_page", $_REQUEST["wiki_license_page"]);
+ $gBitSmarty->assign('wiki_license_page', $_REQUEST["wiki_license_page"]);
}
- if (isset($_REQUEST["wikiSubmitNotice"])) {
- $gBitSystem->storePreference("wikiSubmitNotice", $_REQUEST["wikiSubmitNotice"]);
- $gBitSmarty->assign('wikiSubmitNotice', $_REQUEST["wikiSubmitNotice"]);
+ if (isset($_REQUEST["wiki_submit_notice"])) {
+ $gBitSystem->storePreference("wiki_submit_notice", $_REQUEST["wiki_submit_notice"]);
+ $gBitSmarty->assign('wiki_submit_notice', $_REQUEST["wiki_submit_notice"]);
}
}
$tags = $wikilib->get_tags();
$gBitSmarty->assign_by_ref("tags", $tags);
-$gBitSmarty->assign("maxVersions", $gBitSystem->getPreference("maxVersions", 0));
+$gBitSmarty->assign("max_versions", $gBitSystem->getPreference("max_versions", 0));
$gBitSmarty->assign("keep_versions", $gBitSystem->getPreference("keep_versions", 1));
$gBitSmarty->assign("wiki_feature_copyrights", $gBitSystem->getPreference("wiki_feature_copyrights"));
-$gBitSmarty->assign('wikiLicensePage', $gBitSystem->getPreference("wikiLicensePage"));
-$gBitSmarty->assign('wikiSubmitNotice', $gBitSystem->getPreference("wikiSubmitNotice"));
+$gBitSmarty->assign('wiki_license_page', $gBitSystem->getPreference("wiki_license_page"));
+$gBitSmarty->assign('wiki_submit_notice', $gBitSystem->getPreference("wiki_submit_notice"));
?>
diff --git a/admin/schema_inc.php b/admin/schema_inc.php
index 9cabf34..cedcd5b 100644
--- a/admin/schema_inc.php
+++ b/admin/schema_inc.php
@@ -120,15 +120,15 @@ $gBitInstaller->registerUserPermissions( WIKI_PKG_NAME, array(
// ### Default Preferences
$gBitInstaller->registerPreferences( WIKI_PKG_NAME, array(
- //array( WIKI_PKG_NAME, 'anonCanEdit','n'),
+ //array( WIKI_PKG_NAME, 'anon_can_edit','n'),
array( WIKI_PKG_NAME, 'feature_autolinks','y'),
array( WIKI_PKG_NAME, 'feature_backlinks','y'),
array( WIKI_PKG_NAME, 'feature_dump','y'),
array( WIKI_PKG_NAME, 'feature_history','y'),
- array( WIKI_PKG_NAME, 'feature_lastChanges','y'),
- array( WIKI_PKG_NAME, 'feature_likePages','y'),
+ array( WIKI_PKG_NAME, 'feature_last_changes','y'),
+ array( WIKI_PKG_NAME, 'feature_like_pages','y'),
array( WIKI_PKG_NAME, 'feature_allow_dup_wiki_page_names','y'),
- array( WIKI_PKG_NAME, 'feature_listPages','y'),
+ array( WIKI_PKG_NAME, 'feature_list_pages','y'),
array( WIKI_PKG_NAME, 'feature_page_title','y'),
//array( WIKI_PKG_NAME, 'feature_ranking','n'),
array( WIKI_PKG_NAME, 'feature_sandbox','y'),
@@ -153,7 +153,7 @@ $gBitInstaller->registerPreferences( WIKI_PKG_NAME, array(
//array( WIKI_PKG_NAME, 'feature_wiki_usrlock','n'),
array( WIKI_PKG_NAME, 'feature_wikiwords','y'),
array( WIKI_PKG_NAME, 'keep_versions','1'),
- array( WIKI_PKG_NAME, 'maxVersions','0'),
+ array( WIKI_PKG_NAME, 'max_versions','0'),
array( WIKI_PKG_NAME, 'w_use_db','y'),
//array( WIKI_PKG_NAME, 'w_use_dir',''),
array( WIKI_PKG_NAME, 'warn_on_edit_time','2'),
@@ -183,9 +183,9 @@ $gBitInstaller->registerPreferences( WIKI_PKG_NAME, array(
//array( WIKI_PKG_NAME, 'wiki_uses_slides','n'),
array( WIKI_PKG_NAME, 'wikibook_show_path','y'),
array( WIKI_PKG_NAME, 'wikibook_show_navigation','y'),
- array( WIKI_PKG_NAME, 'wikiHomePage','Welcome'),
- //array( WIKI_PKG_NAME, 'wikiLicensePage',''),
- //array( WIKI_PKG_NAME, 'wikiSubmitNotice',''),
+ array( WIKI_PKG_NAME, 'wiki_home_page','Welcome'),
+ //array( WIKI_PKG_NAME, 'wiki_license_page',''),
+ //array( WIKI_PKG_NAME, 'wiki_submit_notice',''),
) );
if( defined( 'RSS_PKG_NAME' ) ) {
diff --git a/bit_setup_inc.php b/bit_setup_inc.php
index 8548963..398e6fe 100644
--- a/bit_setup_inc.php
+++ b/bit_setup_inc.php
@@ -14,6 +14,6 @@
// Stuff found in kernel that is package dependent - wolff_borg
include_once( WIKI_PKG_PATH.'diff.php' );
- $wikiHomePage = $gBitSystem->getPreference("wikiHomePage", 'HomePage');
+ $wiki_home_page = $gBitSystem->getPreference("wiki_home_page", 'HomePage');
}
?>
diff --git a/index.php b/index.php
index c5f2f1c..757e5e1 100644
--- a/index.php
+++ b/index.php
@@ -1,6 +1,6 @@
<?php
/**
- * $Header: /cvsroot/bitweaver/_bit_wiki/index.php,v 1.5 2006/02/05 17:39:37 squareing Exp $
+ * $Header: /cvsroot/bitweaver/_bit_wiki/index.php,v 1.6 2006/02/06 00:12:23 squareing Exp $
*
* Copyright (c) 2004 bitweaver.org
* Copyright (c) 2003 tikwiki.org
@@ -8,7 +8,7 @@
* All Rights Reserved. See copyright.txt for details and a complete list of authors.
* Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details
*
- * $Id: index.php,v 1.5 2006/02/05 17:39:37 squareing Exp $
+ * $Id: index.php,v 1.6 2006/02/06 00:12:23 squareing Exp $
* @package wiki
* @subpackage functions
*/
@@ -23,16 +23,16 @@ require_once( WIKI_PKG_PATH.'BitPage.php' );
include( LIBERTY_PKG_PATH.'display_structure_inc.php' );
} else {
if ( !isset( $_REQUEST['page'] ) and !isset( $_REQUEST['page_id'] ) ) {
- $_REQUEST['page'] = $gBitSystem->getPreference( 'wikiHomePage', 'HomePage' );
+ $_REQUEST['page'] = $gBitSystem->getPreference( 'wiki_home_page', 'HomePage' );
}
$gHome = new BitPage();
- $wikiHome = $gBitSystem->getPreference("wikiHomePage", 'HomePage');
+ $wikiHome = $gBitSystem->getPreference("wiki_home_page", 'HomePage');
if( !($gHome->pageExists( $wikiHome )) ) {
$homeHash = array(
'title' => (isset( $wikiHome ) ? $wikiHome : 'HomePage'),
'creator_user_id' => ROOT_USER_ID,
'modifier_user_id' => ROOT_USER_ID,
- 'edit' => 'Welcome to '.( $gBitSystem->getPreference( 'siteTitle', 'our site' ) ) );
+ 'edit' => 'Welcome to '.( $gBitSystem->getPreference( 'site_title', 'our site' ) ) );
$gHome->store( $homeHash );
}
diff --git a/like_pages.php b/like_pages.php
index b8cffe5..dba0ec6 100644
--- a/like_pages.php
+++ b/like_pages.php
@@ -1,6 +1,6 @@
<?php
/**
- * $Header: /cvsroot/bitweaver/_bit_wiki/like_pages.php,v 1.5 2006/02/04 19:04:34 squareing Exp $
+ * $Header: /cvsroot/bitweaver/_bit_wiki/like_pages.php,v 1.6 2006/02/06 00:12:23 squareing Exp $
*
* Copyright (c) 2004 bitweaver.org
* Copyright (c) 2003 tikwiki.org
@@ -8,7 +8,7 @@
* All Rights Reserved. See copyright.txt for details and a complete list of authors.
* Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details
*
- * $Id: like_pages.php,v 1.5 2006/02/04 19:04:34 squareing Exp $
+ * $Id: like_pages.php,v 1.6 2006/02/06 00:12:23 squareing Exp $
* @package wiki
* @subpackage functions
*/
@@ -20,7 +20,7 @@ require_once( '../bit_setup_inc.php' );
include_once( WIKI_PKG_PATH.'BitPage.php');
include_once( WIKI_PKG_PATH.'lookup_page_inc.php' );
$gBitSystem->verifyPackage( 'wiki' );
-$gBitSystem->verifyFeature( 'feature_likePages' );
+$gBitSystem->verifyFeature( 'feature_like_pages' );
$gBitSystem->verifyPermission( 'bit_p_view', tra( "Permission denied you cannot view pages like this page" ) );
// Get the page from the request var or default it to HomePage
diff --git a/lookup_page_inc.php b/lookup_page_inc.php
index 2a7f69c..f1840a2 100644
--- a/lookup_page_inc.php
+++ b/lookup_page_inc.php
@@ -1,6 +1,6 @@
<?php
/**
- * $Header: /cvsroot/bitweaver/_bit_wiki/lookup_page_inc.php,v 1.7 2006/02/04 10:32:44 squareing Exp $
+ * $Header: /cvsroot/bitweaver/_bit_wiki/lookup_page_inc.php,v 1.8 2006/02/06 00:12:23 squareing Exp $
*
* Copyright (c) 2004 bitweaver.org
* Copyright (c) 2003 tikwiki.org
@@ -8,7 +8,7 @@
* All Rights Reserved. See copyright.txt for details and a complete list of authors.
* Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details
*
- * $Id: lookup_page_inc.php,v 1.7 2006/02/04 10:32:44 squareing Exp $
+ * $Id: lookup_page_inc.php,v 1.8 2006/02/06 00:12:23 squareing Exp $
* @package wiki
* @subpackage functions
*/
@@ -93,7 +93,7 @@
parse_str($purl["query"], $purlquery);
if (!isset($purlquery["page"])) {
- $purlquery["page"] = $gBitSystem->getPreference( 'wikiHomePage' );
+ $purlquery["page"] = $gBitSystem->getPreference( 'wiki_home_page' );
}
if (isset($_SESSION["edit_lock"])) {
diff --git a/page_history.php b/page_history.php
index 9ba8e16..1735a10 100644
--- a/page_history.php
+++ b/page_history.php
@@ -1,6 +1,6 @@
<?php
/**
- * $Header: /cvsroot/bitweaver/_bit_wiki/page_history.php,v 1.5 2006/01/27 21:57:53 squareing Exp $
+ * $Header: /cvsroot/bitweaver/_bit_wiki/page_history.php,v 1.6 2006/02/06 00:12:23 squareing Exp $
*
* Copyright (c) 2004 bitweaver.org
* Copyright (c) 2003 tikwiki.org
@@ -8,7 +8,7 @@
* All Rights Reserved. See copyright.txt for details and a complete list of authors.
* Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details
*
- * $Id: page_history.php,v 1.5 2006/01/27 21:57:53 squareing Exp $
+ * $Id: page_history.php,v 1.6 2006/02/06 00:12:23 squareing Exp $
* @package wiki
* @subpackage functions
*/
@@ -86,14 +86,14 @@ if (isset($_REQUEST["delete"]) && isset($_REQUEST["hist"])) {
// pagination stuff
$gBitSmarty->assign( 'page', $page = !empty( $_REQUEST['page'] ) ? $_REQUEST['page'] : 1 );
-$offset = ( $page - 1 ) * $gBitSystem->mPrefs['maxRecords'];
-$history = $gContent->getHistory( NULL, NULL, $offset, $gBitSystem->mPrefs['maxRecords'] );
+$offset = ( $page - 1 ) * $gBitSystem->mPrefs['max_records'];
+$history = $gContent->getHistory( NULL, NULL, $offset, $gBitSystem->mPrefs['max_records'] );
$gBitSmarty->assign_by_ref( 'history', $history );
//vd($gContent->getHistoryCount());
// calculate page number
-$numPages = ceil( $gContent->getHistoryCount() / $gBitSystem->mPrefs['maxRecords'] );
+$numPages = ceil( $gContent->getHistoryCount() / $gBitSystem->mPrefs['max_records'] );
$gBitSmarty->assign( 'numPages', $numPages );
diff --git a/print.php b/print.php
index e923d93..dd6cdb8 100644
--- a/print.php
+++ b/print.php
@@ -1,6 +1,6 @@
<?php
/**
- * $Header: /cvsroot/bitweaver/_bit_wiki/print.php,v 1.7 2006/02/04 19:04:35 squareing Exp $
+ * $Header: /cvsroot/bitweaver/_bit_wiki/print.php,v 1.8 2006/02/06 00:12:23 squareing Exp $
*
* Copyright (c) 2004 bitweaver.org
* Copyright (c) 2003 tikwiki.org
@@ -8,7 +8,7 @@
* All Rights Reserved. See copyright.txt for details and a complete list of authors.
* Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details
*
- * $Id: print.php,v 1.7 2006/02/04 19:04:35 squareing Exp $
+ * $Id: print.php,v 1.8 2006/02/06 00:12:23 squareing Exp $
* @package wiki
* @subpackage functions
*/
@@ -50,10 +50,10 @@ if ($count_admin_pvs == 'y' || !$gBitUser->isAdmin()) {
}
// Get page data
$info = $gContent->mInfo;
-if ($gBitSystem->isFeatureActive( 'wiki_feature_copyrights' ) && $gBitSystem->isFeatureActive( 'wiki_feature_copyrights' ) && $gBitSystem->isFeatureActive( 'wikiLicensePage' )) {
+if ($gBitSystem->isFeatureActive( 'wiki_feature_copyrights' ) && $gBitSystem->isFeatureActive( 'wiki_feature_copyrights' ) && $gBitSystem->isFeatureActive( 'wiki_license_page' )) {
// insert license if wiki copyrights enabled
-// $license_info = $wikilib->get_page_info($wikiLicensePage);
-// $wikilib->add_hit($wikiLicensePage);
+// $license_info = $wikilib->get_page_info($wiki_license_page);
+// $wikilib->add_hit($wiki_license_page);
$info["data"] = $info["data"] . "\n<HR>\n" . $license_info["data"];
$_REQUEST['copyrightpage'] = $page;
}
diff --git a/received_pages.php b/received_pages.php
index 6b0657c..fa85479 100644
--- a/received_pages.php
+++ b/received_pages.php
@@ -1,6 +1,6 @@
<?php
/**
- * $Header: /cvsroot/bitweaver/_bit_wiki/Attic/received_pages.php,v 1.5 2006/02/02 08:20:47 squareing Exp $
+ * $Header: /cvsroot/bitweaver/_bit_wiki/Attic/received_pages.php,v 1.6 2006/02/06 00:12:23 squareing Exp $
*
* Copyright (c) 2004 bitweaver.org
* Copyright (c) 2003 tikwiki.org
@@ -8,7 +8,7 @@
* All Rights Reserved. See copyright.txt for details and a complete list of authors.
* Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details
*
- * $Id: received_pages.php,v 1.5 2006/02/02 08:20:47 squareing Exp $
+ * $Id: received_pages.php,v 1.6 2006/02/06 00:12:23 squareing Exp $
* @package wiki
* @subpackage functions
*/
@@ -84,7 +84,7 @@ if (!isset($_REQUEST["offset"])) {
}
if (isset($_REQUEST['page'])) {
$page = &$_REQUEST['page'];
- $offset = ($page - 1) * $maxRecords;
+ $offset = ($page - 1) * $max_records;
}
$gBitSmarty->assign_by_ref('offset', $offset);
if (isset($_REQUEST["find"])) {
@@ -94,18 +94,18 @@ if (isset($_REQUEST["find"])) {
}
$gBitSmarty->assign_by_ref('find', $find);
-$channels = $wikilib->list_received_pages($offset, $maxRecords, $sort_mode, $find);
-$cant_pages = ceil($channels["cant"] / $maxRecords);
+$channels = $wikilib->list_received_pages($offset, $max_records, $sort_mode, $find);
+$cant_pages = ceil($channels["cant"] / $max_records);
$gBitSmarty->assign_by_ref('cant_pages', $cant_pages);
-$gBitSmarty->assign('actual_page', 1 + ($offset / $maxRecords));
-if ($channels["cant"] > ($offset + $maxRecords)) {
- $gBitSmarty->assign('next_offset', $offset + $maxRecords);
+$gBitSmarty->assign('actual_page', 1 + ($offset / $max_records));
+if ($channels["cant"] > ($offset + $max_records)) {
+ $gBitSmarty->assign('next_offset', $offset + $max_records);
} else {
$gBitSmarty->assign('next_offset', -1);
}
// If offset is > 0 then prev_offset
if ($offset > 0) {
- $gBitSmarty->assign('prev_offset', $offset - $maxRecords);
+ $gBitSmarty->assign('prev_offset', $offset - $max_records);
} else {
$gBitSmarty->assign('prev_offset', -1);
}
diff --git a/slideshow.php b/slideshow.php
index 32e9b12..0f62553 100755
--- a/slideshow.php
+++ b/slideshow.php
@@ -1,6 +1,6 @@
<?php
/**
- * $Header: /cvsroot/bitweaver/_bit_wiki/slideshow.php,v 1.6 2006/02/04 19:04:35 squareing Exp $
+ * $Header: /cvsroot/bitweaver/_bit_wiki/slideshow.php,v 1.7 2006/02/06 00:12:23 squareing Exp $
*
* Copyright (c) 2004 bitweaver.org
* Copyright (c) 2003 tikwiki.org
@@ -8,7 +8,7 @@
* All Rights Reserved. See copyright.txt for details and a complete list of authors.
* Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details
*
- * $Id: slideshow.php,v 1.6 2006/02/04 19:04:35 squareing Exp $
+ * $Id: slideshow.php,v 1.7 2006/02/06 00:12:23 squareing Exp $
* @package wiki
* @subpackage functions
*/
@@ -32,10 +32,10 @@ if (!isset($_SESSION["thedate"])) {
// Get the page from the request var or default it to HomePage
if (!isset($_REQUEST["page"])) {
- $_REQUEST["page"] = $wikiHomePage;
+ $_REQUEST["page"] = $wiki_home_page;
- $page = $wikiHomePage;
- $gBitSmarty->assign('page', $wikiHomePage);
+ $page = $wiki_home_page;
+ $gBitSmarty->assign('page', $wiki_home_page);
} else {
$page = $_REQUEST["page"];
diff --git a/templates/edit_page.tpl b/templates/edit_page.tpl
index 444f094..2903244 100644
--- a/templates/edit_page.tpl
+++ b/templates/edit_page.tpl
@@ -1,4 +1,4 @@
-{* $Header: /cvsroot/bitweaver/_bit_wiki/templates/edit_page.tpl,v 1.15 2006/01/30 17:34:24 squareing Exp $ *}
+{* $Header: /cvsroot/bitweaver/_bit_wiki/templates/edit_page.tpl,v 1.16 2006/02/06 00:12:23 squareing Exp $ *}
<div class="floaticon">{bithelp}</div>
<div class="edit wiki">
@@ -214,16 +214,16 @@
<div class="row">
{formlabel label="License"}
{forminput}
- <a href="{$smarty.const.WIKI_PKG_URL}index.php?page={$wikiLicensePage}">{tr}{$wikiLicensePage}{/tr}</a>
+ <a href="{$smarty.const.WIKI_PKG_URL}index.php?page={$wiki_license_page}">{tr}{$wiki_license_page}{/tr}</a>
{formhelp note=""}
{/forminput}
</div>
- {if $wikiSubmitNotice neq ""}
+ {if $wiki_submit_notice neq ""}
<div class="row">
{formlabel label="Important"}
{forminput}
- {$wikiSubmitNotice}
+ {$wiki_submit_notice}
{formhelp note=""}
{/forminput}
</div>
diff --git a/wiki_rss.php b/wiki_rss.php
index 5d35148..98cd4e9 100644
--- a/wiki_rss.php
+++ b/wiki_rss.php
@@ -1,6 +1,6 @@
<?php
/**
- * @version $Header: /cvsroot/bitweaver/_bit_wiki/wiki_rss.php,v 1.6 2006/01/17 00:23:45 squareing Exp $
+ * @version $Header: /cvsroot/bitweaver/_bit_wiki/wiki_rss.php,v 1.7 2006/02/06 00:12:23 squareing Exp $
* @package wiki
* @subpackage functions
*/
@@ -15,8 +15,8 @@ require_once( WIKI_PKG_PATH."BitPage.php" );
$gBitSystem->verifyPackage( 'wiki' );
$gBitSystem->verifyPackage( 'rss' );
-$rss->title = $gBitSystem->getPreference( 'title_rss_wiki', $gBitSystem->mPrefs['siteTitle'].' - '.tra( 'Wiki' ) );
-$rss->description = $gBitSystem->getPreference( 'desc_rss_wiki', $gBitSystem->mPrefs['siteTitle'].' - '.tra( 'RSS Feed' ) );
+$rss->title = $gBitSystem->getPreference( 'title_rss_wiki', $gBitSystem->mPrefs['site_title'].' - '.tra( 'Wiki' ) );
+$rss->description = $gBitSystem->getPreference( 'desc_rss_wiki', $gBitSystem->mPrefs['site_title'].' - '.tra( 'RSS Feed' ) );
// check permission to view wiki pages
if( !$gBitUser->hasPermission( 'bit_p_view' ) ) {
diff --git a/BitPage.php b/BitPage.php
index de81959..164ef23 100644
--- a/BitPage.php
+++ b/BitPage.php
@@ -1,11 +1,11 @@
<?php
/**
- * @version $Header: /cvsroot/bitweaver/_bit_wiki/BitPage.php,v 1.28 2006/02/04 18:40:01 squareing Exp $
+ * @version $Header: /cvsroot/bitweaver/_bit_wiki/BitPage.php,v 1.29 2006/02/06 00:12:23 squareing Exp $
* @package wiki
*
* @author spider <spider@steelsun.com>
*
- * @version $Revision: 1.28 $ $Date: 2006/02/04 18:40:01 $ $Author: squareing $
+ * @version $Revision: 1.29 $ $Date: 2006/02/06 00:12:23 $ $Author: squareing $
*
* Copyright (c) 2004 bitweaver.org
* Copyright (c) 2003 tikwiki.org
@@ -13,7 +13,7 @@
* All Rights Reserved. See copyright.txt for details and a complete list of authors.
* Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details
*
- * $Id: BitPage.php,v 1.28 2006/02/04 18:40:01 squareing Exp $
+ * $Id: BitPage.php,v 1.29 2006/02/06 00:12:23 squareing Exp $
*/
/**
@@ -535,7 +535,7 @@ class BitPage extends LibertyAttachable {
* @param pExistsHash the hash that was returned by LibertyContent::pageExists
* @return array of mInfo data
*/
- function getHistory( $pVersion=NULL, $pUserId=NULL, $pOffset = 0, $maxRecords = -1 ) {
+ function getHistory( $pVersion=NULL, $pUserId=NULL, $pOffset = 0, $max_records = -1 ) {
$ret = NULL;
if( $this->isValid() ) {
global $gBitSystem;
@@ -559,7 +559,7 @@ class BitPage extends LibertyAttachable {
LEFT JOIN `".BIT_DB_PREFIX."users_users` uuc ON (uuc.`user_id` = lc.`user_id`)
WHERE $whereSql $versionSql order by th.`version` desc";
- $result = $this->mDb->query( $query, $bindVars, $maxRecords, $pOffset );
+ $result = $this->mDb->query( $query, $bindVars, $max_records, $pOffset );
$ret = array();
while( !$result->EOF ) {
$aux = $result->fields;
@@ -739,7 +739,7 @@ class BitPage extends LibertyAttachable {
/**
* Generate list of pages
* @param offset Number of the first record to list
* @param maxRecords Number of records to list
* @param sort_mode Order in which the records will be sorted
* @param find Filter to be applied to the list
* @param pUserId If set additionally filter on UserId
@@ -747,7 +747,7 @@ class BitPage extends LibertyAttachable {
* This can take some time to calculate, and so should not normally be enabled
* @param pOrphansOnly If Set list only unattached pages ( ones not used in other content )
*/
- function getList($offset = 0, $maxRecords = -1, $sort_mode = 'title_desc', $find = '', $pUserId=NULL, $pExtras=FALSE, $pOrphansOnly=FALSE, $pGetData=FALSE ) {
+ function getList($offset = 0, $max_records = -1, $sort_mode = 'title_desc', $find = '', $pUserId=NULL, $pExtras=FALSE, $pOrphansOnly=FALSE, $pGetData=FALSE ) {
global $gBitSystem;
if ($sort_mode == 'size_desc') {
$sort_mode = 'page_size_desc';
@@ -768,11 +768,11 @@ class BitPage extends LibertyAttachable {
))) {
$old_offset = $offset;
- $old_maxRecords = $maxRecords;
+ $old_max_records = $max_records;
$old_sort_mode = $sort_mode;
$sort_mode = 'modifier_user_desc';
$offset = 0;
- $maxRecords = -1;
+ $max_records = -1;
}
$mid = '';
@@ -865,12 +865,12 @@ class BitPage extends LibertyAttachable {
AND lcl.`to_content_id` IS NULL";
}
// If sort mode is versions then offset is 0, maxRecords is -1 (again) and sort_mode is nil
// If sort mode is links then offset is 0, maxRecords is -1 (again) and sort_mode is nil
// If sort mode is backlinks then offset is 0, maxRecords is -1 (again) and sort_mode is nil
$this->mDb->StartTrans();
- $result = $this->mDb->query( $query, $bindVars, $maxRecords, $offset );
+ $result = $this->mDb->query( $query, $bindVars, $max_records, $offset );
$cant = $this->mDb->getOne( $query_cant, $bindVars );
$this->mDb->CompleteTrans();
$ret = array();
@@ -892,7 +892,7 @@ class BitPage extends LibertyAttachable {
}
// If sortmode is versions, links or backlinks sort using the ad-hoc function and reduce using old_offse and old_maxRecords
if ($old_sort_mode == 'versions_asc' && !empty( $ret['versions'] ) ) {
usort($ret, 'compare_versions');
}
@@ -925,7 +925,7 @@ class BitPage extends LibertyAttachable {
'backlinks_asc',
'backlinks_desc'
))) {
- $ret = array_slice($ret, $old_offset, $old_maxRecords);
+ $ret = array_slice($ret, $old_offset, $old_max_records);
}
@@ -1237,7 +1237,7 @@ class WikiLib extends BitPage {
}
}
/*shared*/
- function list_received_pages($offset, $maxRecords, $sort_mode = 'title_asc', $find) {
+ function list_received_pages($offset, $max_records, $sort_mode = 'title_asc', $find) {
$bindvars = array();
if ($find) {
$findesc = '%'.strtoupper( $find ).'%';
@@ -1250,7 +1250,7 @@ class WikiLib extends BitPage {
$query = "select * from `".BIT_DB_PREFIX."wiki_received_pages` $mid order by ".$this->mDb->convert_sortmode($sort_mode);
$query_cant = "select count(*) from `".BIT_DB_PREFIX."wiki_received_pages` $mid";
- $result = $this->mDb->query($query,$bindvars,$maxRecords,$offset);
+ $result = $this->mDb->query($query,$bindvars,$max_records,$offset);
$cant = $this->mDb->getOne($query_cant,$bindvars);
$ret = array();
@@ -1283,7 +1283,7 @@ class WikiLib extends BitPage {
// Dumps the database to dump/new.tar
// changed for virtualhost support
function dumpPages() {
- global $wikiHomePage, $gBitSystem, $gBitUser;
+ global $wiki_home_page, $gBitSystem, $gBitUser;
$tar = new tar();
$tar->addFile( $gBitSystem->getStyleCss() );
@@ -1306,7 +1306,7 @@ class WikiLib extends BitPage {
$dat = preg_replace("/edit.php\?page=([^\'\"\$]+)/", "", $dat);
//preg_match_all("/index.php\?page=([^ ]+)/",$dat,$cosas);
//print_r($cosas);
- $data = "<html><head><title>" . $res["title"] . "</title><link rel='StyleSheet' href='".$gBitSystem->getStyleCss()."' type='text/css'></head><body><a class='wiki' href='$wikiHomePage.html'>home</a><br/><h1>" . $res["title"] . "</h1><div class='wikitext'>" . $dat . '</div></body></html>';
+ $data = "<html><head><title>" . $res["title"] . "</title><link rel='StyleSheet' href='".$gBitSystem->getStyleCss()."' type='text/css'></head><body><a class='wiki' href='$wiki_home_page.html'>home</a><br/><h1>" . $res["title"] . "</h1><div class='wikitext'>" . $dat . '</div></body></html>';
$tar->addData($title, $data, $res["last_modified"]);
}
@@ -1318,7 +1318,7 @@ class WikiLib extends BitPage {
$result = $this->mDb->query($query,array($action,1,$t,$gBitUser->mUserId,$_SERVER["REMOTE_ADDR"],''));
}
- function list_extwiki($offset, $maxRecords, $sort_mode, $find) {
+ function list_extwiki($offset, $max_records, $sort_mode, $find) {
$bindvars=array();
if ($find) {
$findesc = '%' . $find . '%';
@@ -1331,7 +1331,7 @@ class WikiLib extends BitPage {
$query = "select * from `".BIT_DB_PREFIX."wiki_ext` $mid order by ".$this->mDb->convert_sortmode($sort_mode);
$query_cant = "select count(*) from `".BIT_DB_PREFIX."wiki_ext` $mid";
- $result = $this->mDb->query($query,$bindvars,$maxRecords,$offset);
+ $result = $this->mDb->query($query,$bindvars,$max_records,$offset);
$cant = $this->mDb->getOne($query_cant,$bindvars);
$ret = array();
@@ -1401,16 +1401,16 @@ class WikiLib extends BitPage {
}
function remove_tag($tagname) {
- global $wikiHomePage, $gBitUser, $gBitSystem;
+ global $wiki_home_page, $gBitUser, $gBitSystem;
$this->mDb->StartTrans();
$query = "delete from `".BIT_DB_PREFIX."wiki_tags` where `tag_name`=?";
$result = $this->mDb->query($query,array($tagname));
$action = "removed tag: $tagname";
$t = $gBitSystem->getUTCTime();
- $homePageId = $this->mDb->getOne( "SELECT `page_id` from `".BIT_DB_PREFIX."wiki_pages` tp INNER JOIN `".BIT_DB_PREFIX."liberty_content` lc ON(tp.`content_id`=lc.`content_id`) WHERE lc.`title`=?", array( $wikiHomePage ) );
+ $homePageId = $this->mDb->getOne( "SELECT `page_id` from `".BIT_DB_PREFIX."wiki_pages` tp INNER JOIN `".BIT_DB_PREFIX."liberty_content` lc ON(tp.`content_id`=lc.`content_id`) WHERE lc.`title`=?", array( $wiki_home_page ) );
$query = "insert into `".BIT_DB_PREFIX."wiki_action_log` (`page_id`, `action`, `page_name`, `last_modified`, `user_id`, `ip`, `comment`) values ( ?,?,?,?,?,?,? )";
- $result = $this->mDb->query($query,array($homePageId, $action,$wikiHomePage,$t,$gBitUser->mUserId,$_SERVER["REMOTE_ADDR"],''));
+ $result = $this->mDb->query($query,array($homePageId, $action,$wiki_home_page,$t,$gBitUser->mUserId,$_SERVER["REMOTE_ADDR"],''));
$this->mDb->CompleteTrans();
return true;
}
@@ -1431,7 +1431,7 @@ class WikiLib extends BitPage {
// This function can be used to store the set of actual pages in the "tags"
// table preserving the state of the wiki under a tag name.
function create_tag($tagname, $comment = '') {
- global $wikiHomePage, $gBitUser, $gBitSystem;
+ global $wiki_home_page, $gBitUser, $gBitSystem;
$this->mDb->StartTrans();
$query = "select * from `".BIT_DB_PREFIX."wiki_pages` tp INNER JOIN `".BIT_DB_PREFIX."liberty_content` lc ON( tp.`content_id`=lc.`content_id` )";
@@ -1447,11 +1447,11 @@ class WikiLib extends BitPage {
$result2 = $this->mDb->query($query,array($res["page_id"],$tagname,$res["title"],$res["hits"],$data,$res["last_modified"],$res["comment"],$res["version"],$res["user_id"],$res["ip"],$res["flag"],$description));
}
- $homePageId = $this->mDb->getOne( "SELECT `page_id` from `".BIT_DB_PREFIX."wiki_pages` tp INNER JOIN `".BIT_DB_PREFIX."liberty_content` lc ON(tp.`content_id`=lc.`content_id`) WHERE lc.`title`=?", array( $wikiHomePage ) );
+ $homePageId = $this->mDb->getOne( "SELECT `page_id` from `".BIT_DB_PREFIX."wiki_pages` tp INNER JOIN `".BIT_DB_PREFIX."liberty_content` lc ON(tp.`content_id`=lc.`content_id`) WHERE lc.`title`=?", array( $wiki_home_page ) );
$action = "created tag: $tagname";
$t = $gBitSystem->getUTCTime();
$query = "insert into `".BIT_DB_PREFIX."wiki_action_log`(`page_id`,`action`,`page_name`,`last_modified`,`user_id`,`ip`,`comment`) values(?,?,?,?,?,?,?)";
- $result = $this->mDb->query($query,array($homePageId,$action,$wikiHomePage,$t,$gBitUser->mUserId,$_SERVER["REMOTE_ADDR"],$comment));
+ $result = $this->mDb->query($query,array($homePageId,$action,$wiki_home_page,$t,$gBitUser->mUserId,$_SERVER["REMOTE_ADDR"],$comment));
$this->mDb->CompleteTrans();
return true;
}
@@ -1459,7 +1459,7 @@ class WikiLib extends BitPage {
// This funcion recovers the state of the wiki using a tag_name from the
// tags table
function restore_tag($tagname) {
- global $wikiHomePage, $gBitUser, $gBitSystem;
+ global $wiki_home_page, $gBitUser, $gBitSystem;
require_once( WIKI_PKG_PATH.'BitPage.php' );
$this->mDb->StartTrans();
@@ -1473,11 +1473,11 @@ class WikiLib extends BitPage {
$tagPage->store( $res );
}
- $homePageId = $this->mDb->getOne( "SELECT `page_id` from `".BIT_DB_PREFIX."wiki_pages` tp INNER JOIN `".BIT_DB_PREFIX."liberty_content` lc ON(tp.`content_id`=lc.`content_id`) WHERE lc.`title`=?", array( $wikiHomePage ) );
+ $homePageId = $this->mDb->getOne( "SELECT `page_id` from `".BIT_DB_PREFIX."wiki_pages` tp INNER JOIN `".BIT_DB_PREFIX."liberty_content` lc ON(tp.`content_id`=lc.`content_id`) WHERE lc.`title`=?", array( $wiki_home_page ) );
$action = "recovered tag: $tagname";
$t = $gBitSystem->getUTCTime();
$query = "insert into `".BIT_DB_PREFIX."wiki_action_log`(`page_id`, `action`, `page_name`, `last_modified`, `user_id`, `ip`, `comment`) values (?,?,?,?,?,?,?)";
- $result = $this->mDb->query($query,array($homePageId,$action,$wikiHomePage,$t, $gBitUser->mUserId,$_SERVER["REMOTE_ADDR"],''));
+ $result = $this->mDb->query($query,array($homePageId,$action,$wiki_home_page,$t, $gBitUser->mUserId,$_SERVER["REMOTE_ADDR"],''));
$this->mDb->CompleteTrans();
return true;
}
@@ -739,7 +739,7 @@ class BitPage extends LibertyAttachable {
* Generate list of pages
* @param offset Number of the first record to list
- * @param maxRecords Number of records to list
+ * @param max_records Number of records to list
* @param sort_mode Order in which the records will be sorted
* @param find Filter to be applied to the list
@@ -865,12 +865,12 @@ class BitPage extends LibertyAttachable {
AND lcl.`to_content_id` IS NULL";
}
- // If sort mode is versions then offset is 0, maxRecords is -1 (again) and sort_mode is nil
- // If sort mode is links then offset is 0, maxRecords is -1 (again) and sort_mode is nil
- // If sort mode is backlinks then offset is 0, maxRecords is -1 (again) and sort_mode is nil
+ // If sort mode is versions then offset is 0, max_records is -1 (again) and sort_mode is nil
+ // If sort mode is links then offset is 0, max_records is -1 (again) and sort_mode is nil
+ // If sort mode is backlinks then offset is 0, max_records is -1 (again) and sort_mode is nil
$this->mDb->StartTrans();
@@ -892,7 +892,7 @@ class BitPage extends LibertyAttachable {
}
- // If sortmode is versions, links or backlinks sort using the ad-hoc function and reduce using old_offse and old_maxRecords
+ // If sortmode is versions, links or backlinks sort using the ad-hoc function and reduce using old_offse and old_max_records
if ($old_sort_mode == 'versions_asc' && !empty( $ret['versions'] ) ) {
usort($ret, 'compare_versions');
diff --git a/list_pages.php b/list_pages.php
index 03f7a95..6650e91 100644
--- a/list_pages.php
+++ b/list_pages.php
@@ -1,6 +1,6 @@
<?php
/**
- * $Header: /cvsroot/bitweaver/_bit_wiki/list_pages.php,v 1.5 2005/12/26 12:27:43 squareing Exp $
+ * $Header: /cvsroot/bitweaver/_bit_wiki/list_pages.php,v 1.6 2006/02/06 00:12:23 squareing Exp $
*
* Copyright (c) 2004 bitweaver.org
* Copyright (c) 2003 tikwiki.org
@@ -8,7 +8,7 @@
* All Rights Reserved. See copyright.txt for details and a complete list of authors.
* Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details
*
- * $Id: list_pages.php,v 1.5 2005/12/26 12:27:43 squareing Exp $
+ * $Id: list_pages.php,v 1.6 2006/02/06 00:12:23 squareing Exp $
* @package wiki
* @subpackage functions
*/
@@ -21,7 +21,7 @@ require_once( WIKI_PKG_PATH.'BitPage.php' );
$gBitSystem->verifyPackage( 'wiki' );
-$gBitSystem->verifyFeature( 'feature_listPages' );
+$gBitSystem->verifyFeature( 'feature_list_pages' );
// Now check permissions to access this page
$gBitSystem->verifyPermission( 'bit_p_view' );
@@ -73,7 +73,7 @@ if ( empty( $_REQUEST["sort_mode"] ) ) {
}
$gBitSmarty->assign_by_ref('sort_mode', $sort_mode);
// If offset is set use it if not then use offset =0
// use the maxRecords php variable to set the limit
// if sortMode is not set then use last_modified_desc
if (!isset($_REQUEST["offset"])) {
$offset = 0;
@@ -82,7 +82,7 @@ if (!isset($_REQUEST["offset"])) {
}
if (isset($_REQUEST['page'])) {
$page = &$_REQUEST['page'];
- $offset = ($page - 1) * $maxRecords;
+ $offset = ($page - 1) * $max_records;
}
$gBitSmarty->assign_by_ref('offset', $offset);
if (isset($_REQUEST["find"])) {
@@ -94,20 +94,20 @@ $gBitSmarty->assign_by_ref('find', $find);
// Get a list of last changes to the Wiki database
$Content = new BitPage();
$sort_mode = preg_replace( '/^user_/', 'creator_user_', $sort_mode );
-$listpages = $Content->getList( $offset, $maxRecords, $sort_mode, $find, NULL, TRUE );
+$listpages = $Content->getList( $offset, $max_records, $sort_mode, $find, NULL, TRUE );
// If there're more records then assign next_offset
-$cant_pages = ceil($listpages["cant"] / $maxRecords);
+$cant_pages = ceil($listpages["cant"] / $max_records);
$gBitSmarty->assign_by_ref('cant_pages', $cant_pages);
$gBitSmarty->assign_by_ref('pagecount', $listpages['cant']);
-$gBitSmarty->assign('actual_page', 1 + ($offset / $maxRecords));
-if ($listpages["cant"] > ($offset + $maxRecords)) {
- $gBitSmarty->assign('next_offset', $offset + $maxRecords);
+$gBitSmarty->assign('actual_page', 1 + ($offset / $max_records));
+if ($listpages["cant"] > ($offset + $max_records)) {
+ $gBitSmarty->assign('next_offset', $offset + $max_records);
} else {
$gBitSmarty->assign('next_offset', -1);
}
// If offset is > 0 then prev_offset
if ($offset > 0) {
- $gBitSmarty->assign('prev_offset', $offset - $maxRecords);
+ $gBitSmarty->assign('prev_offset', $offset - $max_records);
} else {
$gBitSmarty->assign('prev_offset', -1);
}
@@ -73,7 +73,7 @@ if ( empty( $_REQUEST["sort_mode"] ) ) {
$gBitSmarty->assign_by_ref('sort_mode', $sort_mode);
// If offset is set use it if not then use offset =0
-// use the maxRecords php variable to set the limit
+// use the max_records php variable to set the limit
// if sortMode is not set then use last_modified_desc
if (!isset($_REQUEST["offset"])) {
diff --git a/orphan_pages.php b/orphan_pages.php
index 30265de..eab5aab 100644
--- a/orphan_pages.php
+++ b/orphan_pages.php
@@ -1,6 +1,6 @@
<?php
/**
- * $Header: /cvsroot/bitweaver/_bit_wiki/orphan_pages.php,v 1.4 2005/08/01 18:42:04 squareing Exp $
+ * $Header: /cvsroot/bitweaver/_bit_wiki/orphan_pages.php,v 1.5 2006/02/06 00:12:23 squareing Exp $
*
* Copyright (c) 2004 bitweaver.org
* Copyright (c) 2003 tikwiki.org
@@ -8,7 +8,7 @@
* All Rights Reserved. See copyright.txt for details and a complete list of authors.
* Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details
*
- * $Id: orphan_pages.php,v 1.4 2005/08/01 18:42:04 squareing Exp $
+ * $Id: orphan_pages.php,v 1.5 2006/02/06 00:12:23 squareing Exp $
* @package wiki
* @subpackage functions
*/
@@ -22,7 +22,7 @@ $BitPage = new BitPage();
$gBitSystem->verifyPackage( 'wiki' );
-$gBitSystem->verifyFeature( 'feature_listPages' );
+$gBitSystem->verifyFeature( 'feature_list_pages' );
// Now check permissions to access this page
$gBitSystem->verifyPermission( 'bit_p_view' );
@@ -74,7 +74,7 @@ if ( empty( $_REQUEST["sort_mode"] ) ) {
}
$gBitSmarty->assign_by_ref('sort_mode', $sort_mode);
// If offset is set use it if not then use offset =0
// use the maxRecords php variable to set the limit
// if sortMode is not set then use last_modified_desc
if (!isset($_REQUEST["offset"])) {
$offset = 0;
@@ -83,7 +83,7 @@ if (!isset($_REQUEST["offset"])) {
}
if (isset($_REQUEST['page'])) {
$page = &$_REQUEST['page'];
- $offset = ($page - 1) * $maxRecords;
+ $offset = ($page - 1) * $max_records;
}
$gBitSmarty->assign_by_ref('offset', $offset);
if (isset($_REQUEST["find"])) {
@@ -95,20 +95,20 @@ $gBitSmarty->assign('find', $find);
// Get a list of last changes to the Wiki database
$Content = new BitPage();
$sort_mode = preg_replace( '/^user_/', 'creator_user_', $sort_mode );
-$listpages = $Content->getList( $offset, $maxRecords, $sort_mode, $find, NULL, TRUE, TRUE );
+$listpages = $Content->getList( $offset, $max_records, $sort_mode, $find, NULL, TRUE, TRUE );
// If there're more records then assign next_offset
-$cant_pages = ceil($listpages["cant"] / $maxRecords);
+$cant_pages = ceil($listpages["cant"] / $max_records);
$gBitSmarty->assign_by_ref('cant_pages', $cant_pages);
$gBitSmarty->assign_by_ref('pagecount', $listpages['cant']);
-$gBitSmarty->assign('actual_page', 1 + ($offset / $maxRecords));
-if ($listpages["cant"] > ($offset + $maxRecords)) {
- $gBitSmarty->assign('next_offset', $offset + $maxRecords);
+$gBitSmarty->assign('actual_page', 1 + ($offset / $max_records));
+if ($listpages["cant"] > ($offset + $max_records)) {
+ $gBitSmarty->assign('next_offset', $offset + $max_records);
} else {
$gBitSmarty->assign('next_offset', -1);
}
// If offset is > 0 then prev_offset
if ($offset > 0) {
- $gBitSmarty->assign('prev_offset', $offset - $maxRecords);
+ $gBitSmarty->assign('prev_offset', $offset - $max_records);
} else {
$gBitSmarty->assign('prev_offset', -1);
}
@@ -74,7 +74,7 @@ if ( empty( $_REQUEST["sort_mode"] ) ) {
$gBitSmarty->assign_by_ref('sort_mode', $sort_mode);
// If offset is set use it if not then use offset =0
-// use the maxRecords php variable to set the limit
+// use the max_records php variable to set the limit
// if sortMode is not set then use last_modified_desc
if (!isset($_REQUEST["offset"])) {